@@ -23,7 +23,20 @@
    lat.center <- MyMap[[1]];
    lon.center <- MyMap[[2]];
    if (missing(zoom)) zoom <- MyMap[[3]];
-       
+     
+   #account for "jumps" at longitude boundaries -180/180
+   #browser()
+   lonLeft = as.numeric(MyMap$BBOX$ll)[2] #["lon"]
+   lonRight = as.numeric(MyMap$BBOX$ur)[2] #["lon"]
+   
+   if (lonRight*lonLeft < 0){#sign change !
+     #print("fixing the jump at the boundaries")
+     if (MyMap$lon.center < 0){#subtract 360 from all positive longitude values:
+       lon[lon>0] = lon[lon>0]-360
+     } else if (MyMap$lon.center > 0){#add 360 to all negative longitude values:
+       lon[lon<0] = lon[lon<0]+360
+     }
+   }
    mypoints <- LatLon2XY(lat,lon,zoom);
    mycenter <- LatLon2XY(lat.center,lon.center,zoom);
    
